==> gottet-1.1.1-1-src.tar.xz: gottet-1.1.1/translations/gottet_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>Board</name>
    <message>
        <location filename="../src/board.cpp" line="103"/>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="103"/>
        <source>End the current game?</source>
        <translation>Stop het huidige spel</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="189"/>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;Gepauzeerd&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Klik om door te gaan met spelen.</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="419"/>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;Einde Spel!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Klik om een nieuw spel te starten.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="52"/>
        <source>Select application language:</source>
        <translation>Selecteer taal:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="55"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Systeem taal&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="175"/>
        <source>Note</source>
        <translation>Notitie</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="175"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Herstart de applicatie om de taalverandering te activeren</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <location filename="../src/score_board.cpp" line="33"/>
        <source>Gottet Scores</source>
        <translation>Gottet Scores</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Level</source>
        <translation>Niveau</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Lines</source>
        <translation>Lijnen</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Score</source>
        <translation>Score</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="52"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/main.cpp" line="30"/>
        <location filename="../src/window.cpp" line="219"/>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="88"/>
        <source>Click to start a new game.</source>
        <translation>Klik om een nieuw spel te starten</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="106"/>
        <source>&amp;Game</source>
        <translation>&amp;Spel</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="107"/>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="108"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pauze</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="108"/>
        <location filename="../src/window.cpp" line="110"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="110"/>
        <source>&amp;Resume</source>
        <translation>&amp;Hervatten</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="113"/>
        <source>&amp;Scores</source>
        <translation>&amp;Scores</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="115"/>
        <source>&amp;Quit</source>
        <translation>&amp;Stop</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="118"/>
        <source>&amp;Settings</source>
        <translation>&amp;Instellingen</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="119"/>
        <source>Application &amp;Language...</source>
        <translation>Taal van de applicatie</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="121"/>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="122"/>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="124"/>
        <source>About &amp;Qt</source>
        <translation>Over &amp;Qt</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="139"/>
        <source>Next Piece</source>
        <translation>Volgende stuk</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="141"/>
        <source>Level</source>
        <translation>Niveau</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="143"/>
        <source>Removed Lines</source>
        <translation>Verwijder lijnen</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="145"/>
        <source>Score</source>
        <translation>Score</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="218"/>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="220"/>
        <source>A tetris clone I made for my wife</source>
        <translation>Een tetris kloon voor mijn vrouw</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="221"/>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="222"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Gepubliseerd onder de &lt;a href=%1&gt;GPL 3&lt;/a&gt; licentie</translation>
    </message>
</context>
</TS>

==> gottet-1.1.3-1-src.tar.xz: gottet-1.1.3/translations/gottet_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Stop het huidige spel</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;Gepauzeerd&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Klik om door te gaan met spelen.</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;Einde Spel!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Klik om een nieuw spel te starten.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selecteer taal:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Systeem taal&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Notitie</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Herstart de applicatie om de taalverandering te activeren</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <source>Gottet Scores</source>
        <translation>Gottet Scores</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Niveau</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>Lijnen</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Score</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Klik om een nieuw spel te starten</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Spel</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Resume</source>
        <translation>&amp;Hervatten</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Scores</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Stop</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Instellingen</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Taal van de applicatie</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Over &amp;Qt</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>Volgende stuk</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Niveau</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>Verwijder lijnen</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Score</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <source>A tetris clone I made for my wife</source>
        <translation>Een tetris kloon voor mijn vrouw</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Gepubliseerd onder de &lt;a href=%1&gt;GPL 3&lt;/a&gt; licentie</translation>
    </message>
</context>
</TS>
